@@ -14,7 +14,7 @@ class Addon(Model):
     "avalara_service_type", "sku", "accounting_code", "accounting_category1", "accounting_category2", \
     "accounting_category3", "accounting_category4", "is_shippable", "shipping_frequency_period", \
     "shipping_frequency_period_unit", "resource_version", "updated_at", "price_in_decimal", "included_in_mrr", \
-    "invoice_notes", "taxable", "tax_profile_id", "meta_data", "tiers", "show_description_in_invoices", \
+    "channel", "invoice_notes", "taxable", "tax_profile_id", "meta_data", "tiers", "show_description_in_invoices", \
     "show_description_in_quotes"]
 
 
@@ -23,7 +23,7 @@ class Addon(Model):
         return request.send('post', request.uri_path("addons"), params, env, headers)
 
     @staticmethod
-    def update(id, params=None, env=None, headers=None):
+    def update(id, params, env=None, headers=None):
         return request.send('post', request.uri_path("addons",id), params, env, headers)
 
     @staticmethod
