@@ -6,7 +6,8 @@ from chargebee import APIError
 class AttachedItem(Model):
 
     fields = ["id", "parent_item_id", "item_id", "type", "status", "quantity", "quantity_in_decimal", \
-    "billing_cycles", "charge_on_event", "charge_once", "created_at", "resource_version", "updated_at"]
+    "billing_cycles", "charge_on_event", "charge_once", "created_at", "resource_version", "updated_at", \
+    "channel"]
 
 
     @staticmethod
