@@ -5,5 +5,5 @@ from chargebee import APIError
 
 class Download(Model):
 
-    fields = ["download_url", "valid_till"]
+    fields = ["download_url", "valid_till", "mime_type"]
 
