@@ -5,10 +5,10 @@ from chargebee import APIError
 
 class Invoice(Model):
     class LineItem(Model):
-      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "unit_amount_in_decimal", "quantity_in_decimal", "amount_in_decimal", "discount_amount", "item_level_discount_amount", "description", "entity_description", "entity_type", "tax_exempt_reason", "entity_id", "customer_id"]
+      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "unit_amount_in_decimal", "quantity_in_decimal", "amount_in_decimal", "discount_amount", "item_level_discount_amount", "reference_line_item_id", "description", "entity_description", "entity_type", "tax_exempt_reason", "entity_id", "customer_id"]
       pass
     class Discount(Model):
-      fields = ["amount", "description", "entity_type", "entity_id"]
+      fields = ["amount", "description", "entity_type", "entity_id", "coupon_set_code"]
       pass
     class LineItemDiscount(Model):
       fields = ["line_item_id", "discount_type", "coupon_id", "entity_id", "discount_amount"]
@@ -44,11 +44,14 @@ class Invoice(Model):
       fields = ["entity_type", "note", "entity_id"]
       pass
     class ShippingAddress(Model):
-      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
+      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status", "index"]
       pass
     class BillingAddress(Model):
       fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
       pass
+    class Einvoice(Model):
+      fields = ["id", "status", "message"]
+      pass
 
     fields = ["id", "po_number", "customer_id", "subscription_id", "recurring", "status", "vat_number", \
     "price_type", "date", "due_date", "net_term_days", "exchange_rate", "currency_code", "total", \
@@ -59,7 +62,8 @@ class Invoice(Model):
     "amount_to_collect", "round_off_amount", "line_items", "discounts", "line_item_discounts", "taxes", \
     "line_item_taxes", "line_item_tiers", "linked_payments", "dunning_attempts", "applied_credits", \
     "adjustment_credit_notes", "issued_credit_notes", "linked_orders", "notes", "shipping_address", \
-    "billing_address", "payment_owner", "void_reason_code", "deleted", "vat_number_prefix"]
+    "billing_address", "einvoice", "payment_owner", "void_reason_code", "deleted", "vat_number_prefix", \
+    "channel", "business_entity_id"]
 
 
     @staticmethod
@@ -94,6 +98,10 @@ class Invoice(Model):
     def apply_payments(id, params=None, env=None, headers=None):
         return request.send('post', request.uri_path("invoices",id,"apply_payments"), params, env, headers)
 
+    @staticmethod
+    def sync_usages(id, env=None, headers=None):
+        return request.send('post', request.uri_path("invoices",id,"sync_usages"), None, env, headers)
+
     @staticmethod
     def apply_credits(id, params=None, env=None, headers=None):
         return request.send('post', request.uri_path("invoices",id,"apply_credits"), params, env, headers)
@@ -118,6 +126,10 @@ class Invoice(Model):
     def pdf(id, params=None, env=None, headers=None):
         return request.send('post', request.uri_path("invoices",id,"pdf"), params, env, headers)
 
+    @staticmethod
+    def download_einvoice(id, env=None, headers=None):
+        return request.send('get', request.uri_path("invoices",id,"download_einvoice"), None, env, headers)
+
     @staticmethod
     def add_charge(id, params, env=None, headers=None):
         return request.send('post', request.uri_path("invoices",id,"add_charge"), params, env, headers)
@@ -173,3 +185,7 @@ class Invoice(Model):
     @staticmethod
     def update_details(id, params=None, env=None, headers=None):
         return request.send('post', request.uri_path("invoices",id,"update_details"), params, env, headers)
+
+    @staticmethod
+    def resend_einvoice(id, env=None, headers=None):
+        return request.send('post', request.uri_path("invoices",id,"resend_einvoice"), None, env, headers)
