@@ -8,7 +8,7 @@ class Order(Model):
       fields = ["id", "invoice_id", "invoice_line_item_id", "unit_price", "description", "amount", "fulfillment_quantity", "fulfillment_amount", "tax_amount", "amount_paid", "amount_adjusted", "refundable_credits_issued", "refundable_credits", "is_shippable", "sku", "status", "entity_type", "item_level_discount_amount", "discount_amount", "entity_id"]
       pass
     class ShippingAddress(Model):
-      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
+      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status", "index"]
       pass
     class BillingAddress(Model):
       fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
@@ -34,7 +34,8 @@ class Order(Model):
     "status_update_at", "delivered_at", "shipped_at", "resource_version", "updated_at", "cancelled_at", \
     "resent_status", "is_resent", "original_order_id", "order_line_items", "shipping_address", "billing_address", \
     "discount", "sub_total", "total", "line_item_taxes", "line_item_discounts", "linked_credit_notes", \
-    "deleted", "currency_code", "is_gifted", "gift_note", "gift_id", "resend_reason", "resent_orders"]
+    "deleted", "currency_code", "is_gifted", "gift_note", "gift_id", "resend_reason", "resent_orders", \
+    "business_entity_id"]
 
 
     @staticmethod
