@@ -25,8 +25,8 @@ class Plan(Model):
     "sku", "accounting_code", "accounting_category1", "accounting_category2", "accounting_category3", \
     "accounting_category4", "is_shippable", "shipping_frequency_period", "shipping_frequency_period_unit", \
     "resource_version", "updated_at", "giftable", "claim_url", "free_quantity_in_decimal", "price_in_decimal", \
-    "invoice_notes", "taxable", "tax_profile_id", "meta_data", "tiers", "applicable_addons", "attached_addons", \
-    "event_based_addons", "show_description_in_invoices", "show_description_in_quotes"]
+    "channel", "invoice_notes", "taxable", "tax_profile_id", "meta_data", "tiers", "applicable_addons", \
+    "attached_addons", "event_based_addons", "show_description_in_invoices", "show_description_in_quotes"]
 
 
     @staticmethod
@@ -34,7 +34,7 @@ class Plan(Model):
         return request.send('post', request.uri_path("plans"), params, env, headers)
 
     @staticmethod
-    def update(id, params=None, env=None, headers=None):
+    def update(id, params, env=None, headers=None):
         return request.send('post', request.uri_path("plans",id), params, env, headers)
 
     @staticmethod
