@@ -8,7 +8,7 @@ class Subscription(Model):
       fields = ["item_price_id", "item_type", "quantity", "quantity_in_decimal", "metered_quantity", "last_calculated_at", "unit_price", "unit_price_in_decimal", "amount", "amount_in_decimal", "free_quantity", "free_quantity_in_decimal", "trial_end", "billing_cycles", "service_period_days", "charge_on_event", "charge_once", "charge_on_option"]
       pass
     class ItemTier(Model):
-      fields = ["item_price_id", "starting_unit", "ending_unit", "price", "starting_unit_in_decimal", "ending_unit_in_decimal", "price_in_decimal"]
+      fields = ["item_price_id", "starting_unit", "ending_unit", "price", "starting_unit_in_decimal", "ending_unit_in_decimal", "price_in_decimal", "index"]
       pass
     class ChargedItem(Model):
       fields = ["item_price_id", "last_charged_at"]
@@ -26,7 +26,7 @@ class Subscription(Model):
       fields = ["coupon_id", "apply_till", "applied_count", "coupon_code"]
       pass
     class ShippingAddress(Model):
-      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status"]
+      fields = ["first_name", "last_name", "email", "company", "phone", "line1", "line2", "line3", "city", "state_code", "state", "country", "zip", "validation_status", "index"]
       pass
     class ReferralInfo(Model):
       fields = ["referral_code", "coupon_code", "referrer_id", "external_reference_id", "reward_status", "referral_system", "account_id", "campaign_id", "external_campaign_id", "friend_offer_type", "referrer_reward_type", "notify_referral_system", "destination_url", "post_purchase_widget_enabled"]
@@ -34,6 +34,9 @@ class Subscription(Model):
     class ContractTerm(Model):
       fields = ["id", "status", "contract_start", "contract_end", "billing_cycle", "action_at_term_end", "total_contract_value", "cancellation_cutoff_period", "created_at", "subscription_id", "remaining_billing_cycles"]
       pass
+    class Discount(Model):
+      fields = ["id", "invoice_name", "type", "percentage", "amount", "currency_code", "duration_type", "period", "period_unit", "included_in_mrr", "apply_on", "item_price_id", "created_at", "apply_till", "applied_count", "coupon_id", "index"]
+      pass
 
     fields = ["id", "currency_code", "plan_id", "plan_quantity", "plan_unit_price", "setup_fee", \
     "billing_period", "billing_period_unit", "start_date", "trial_end", "remaining_billing_cycles", \
@@ -44,11 +47,12 @@ class Subscription(Model):
     "cancelled_at", "cancel_reason", "affiliate_token", "created_from_ip", "resource_version", "updated_at", \
     "has_scheduled_advance_invoices", "has_scheduled_changes", "payment_source_id", "plan_free_quantity_in_decimal", \
     "plan_amount_in_decimal", "cancel_schedule_created_at", "offline_payment_method", "channel", \
-    "subscription_items", "item_tiers", "charged_items", "due_invoices_count", "due_since", "total_dues", \
-    "mrr", "exchange_rate", "base_currency_code", "addons", "event_based_addons", "charged_event_based_addons", \
-    "coupon", "coupons", "shipping_address", "referral_info", "invoice_notes", "meta_data", "metadata", \
-    "deleted", "changes_scheduled_at", "contract_term", "cancel_reason_code", "free_period", "free_period_unit", \
-    "create_pending_invoices", "auto_close_invoices"]
+    "net_term_days", "subscription_items", "item_tiers", "charged_items", "due_invoices_count", \
+    "due_since", "total_dues", "mrr", "exchange_rate", "base_currency_code", "addons", "event_based_addons", \
+    "charged_event_based_addons", "coupon", "coupons", "shipping_address", "referral_info", "invoice_notes", \
+    "meta_data", "metadata", "deleted", "changes_scheduled_at", "contract_term", "cancel_reason_code", \
+    "free_period", "free_period_unit", "create_pending_invoices", "auto_close_invoices", "discounts", \
+    "business_entity_id"]
 
 
     @staticmethod
@@ -75,6 +79,10 @@ class Subscription(Model):
     def contract_terms_for_subscription(id, params=None, env=None, headers=None):
         return request.send('get', request.uri_path("subscriptions",id,"contract_terms"), params, env, headers)
 
+    @staticmethod
+    def list_discounts(id, params=None, env=None, headers=None):
+        return request.send('get', request.uri_path("subscriptions",id,"discounts"), params, env, headers)
+
     @staticmethod
     def retrieve(id, env=None, headers=None):
         return request.send('get', request.uri_path("subscriptions",id), None, env, headers)
@@ -151,6 +159,10 @@ class Subscription(Model):
     def import_contract_term(id, params=None, env=None, headers=None):
         return request.send('post', request.uri_path("subscriptions",id,"import_contract_term"), params, env, headers)
 
+    @staticmethod
+    def import_unbilled_charges(id, params, env=None, headers=None):
+        return request.send('post', request.uri_path("subscriptions",id,"import_unbilled_charges"), params, env, headers)
+
     @staticmethod
     def import_for_items(id, params, env=None, headers=None):
         return request.send('post', request.uri_path("customers",id,"import_for_items"), params, env, headers)
